@@ -70,12 +70,14 @@ def __display_files(files):
     doc = yattag.Doc()
     with doc.tag("table"):
         with doc.tag("tr"):
+            doc.line("th", "ID")
             doc.line("th", "Name")
             doc.line("th", "Date")
             doc.line("th", "Size")
         if len(files) > 0:
-            for f in files:
+            for i, f in enumerate(files):
                 with doc.tag("tr"):
+                    doc.line("td", str(i + 1))
                     with doc.tag("td"):
                         doc.line("a", f["name"], href=f["url"])
                     doc.line("td", f["date"])
@@ -84,6 +86,37 @@ def __display_files(files):
             doc.line("td", "No files available", colspan="3")
     return HTML(doc.getvalue())
 
+# Must specify either numeric file_id or file_name.
+# If local_file_name is not specified, will use name of uploaded file.
+def download_client_file(file_id=None, file_name=None, local_file_name=None, org_id=None, region=None, env=None):
+    c = load_config(env=env)
+    if region == None:
+        region = c.get("REGION")
+    if org_id == None:
+        org_id = c.get_organization()
+    files = __list_files("download", region=region, org_id=org_id, env=env)
+    if file_name != None:
+        for f in files:
+            if f["name"] == file_name:
+                file = f
+                break
+    elif file_id != None:
+        file = files[file_id - 1]
+    else:
+        raise RuntimeError("Must specify either file_id or file_name")
+    if not file:
+        raise RuntimeError("File not found")
+    if not local_file_name:
+        local_file_name = file["name"]
+    print("Downloading file " + file["name"] + " (" + file["size"] + ")")
+    resp = requests.get(file["url"])
+    if resp.status_code == 200:
+        with open(local_file_name, "wb") as local_file:
+            local_file.write(resp.content)
+        print("Successfully written file to " + local_file_name)
+    else:
+        raise RuntimeError(resp.status_code)
+
 def show_org(env=None):
     c = load_config(env=env)
     print("Organization Name: " + c.get_organization_name())
